#
# spec file for package bookworm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bookworm
Version:        1.1.1
Release:        lp152.2.11
Summary:        E-book reader
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://babluboy.github.io/bookworm
Source:         https://github.com/babluboy/bookworm/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite) >= 0.5
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(sqlite3) >= 3.5.9
BuildRequires:  pkgconfig(webkit2gtk-4.0) >= 2.16.0
# Check list of dependencies
BuildRequires:  html2text
BuildRequires:  poppler-tools
Requires:       html2text
Requires:       poppler-tools
Recommends:     unrar
Recommends:     unzip
Recommends:     %{name}-lang

%description
An eBook reader for Elementary OS.

It uses poppler for decoding and read formats like EPUB, PDF, mobi, cbr, etc.

%lang_package

%prep
%setup -q

chmod -x AUTHORS

%build
%cmake \
    -DGSETTINGS_COMPILE=OFF

make %{?_smp_mflags}

%install
%cmake_install

# fix env-script-interpreter
pushd %{buildroot}%{_datadir}
for _file in $(grep -rl '^\#\!'); do
   find -name ${_file##*/} -type f -executable -exec sed '/^\#\!/s/env\ \+//' -i {} \;
done
popd

# fix wrong-icon-size
_file=$(find -name %{name}.png)
_count=$(echo "$_file" | wc -l)
for _file in $_file; do
  ((_count -- ))
  _width=$(identify -format %w $_file)
  _height=$(identify -format %h $_file)
  _size+=$'\n'$(echo "${_width}x$_height$_file")
  [ "$_count" -eq 0 ] || continue
  _file=$(echo "$_size" | sort -rn | grep -m1 .)
  ls %{_datadir}/icons/hicolor | grep '[0-9]x[0-9]' | sort -n | while read _size; do
    if [ "${_file%x*}" -ge ${_size%x*} ]; then
      mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${_size}/apps
      convert -strip ${_file#*./} -resize $_size \
        %{buildroot}%{_datadir}/icons/hicolor/${_size}/apps/${_file##*/}
    fi
  done
done

# remove executable flags
find %{buildroot} -name \*.txt -exec chmod 0644 {} +

%suse_update_desktop_file -r com.github.babluboy.bookworm GTK Office Viewer
%find_lang com.github.babluboy.bookworm %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/com.github.babluboy.bookworm
%{_datadir}/applications/com.github.babluboy.bookworm.desktop
%{_datadir}/glib-2.0/schemas/com.github.babluboy.bookworm.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*bookworm*.??g
%{_datadir}/metainfo/com.github.babluboy.bookworm.appdata.xml
%{_datadir}/bookworm/
%{_datadir}/contractor/

%files lang -f %{name}.lang

%changelog
* Tue Oct 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * Updated version for libwebkit2gtk-4.0
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Updated for Appcenter Juno release
  * Fixed CSS causing overlapping text (Issue #210)
  * Updated CSS to work for both Loki and Juno
  * Removed stateful from SimpleAction on context menu (Issue
    [#203])
  * Added functionality for dictionary word lookup (Issue #185)
  * Fix to prevent external links to be loaded on Bookworm (Issue
    [#180])
  * Changes to add icons/files to GResource (Issue #81)
  * Added html2text to ReadMe for build instructions
  * Merge pull request #204 from fabianfreyer/master
  * Install scripts with group permissions
  * Changes to add highlight colour to prefferences menu (Issue
    [#202])
  * Merge branch 'origin/master' into Weblate
  * Update desktop entry to use standardised Keywords key.
  * Fix spelling of 'successfully'.
- Remove obsolete macros
- Spec file cleanup
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 1.0.0:
  * Updated snapcraft.yaml to fix DBUS issue
  * Updated snapcraft to old data
  * Update snapcraft.yaml
  * Updated snapcraft for granite0.5
  * changing icon path to data directory
  * Added snapcraft badge
  * Updated snapcraft for snap release
  * Fixes for loading a book from right click in Files
  * Fixed the issue of cover image being stretched (Issue #19)
  * Adjusted scrollbar on the reading view to expand for easier
    mouse grabing (Issue #175)
  * Merge branch 'loki' of https://github.com/babluboy/bookworm
  * Fix for table of contents not using anchors correctly (Isse
    [#154])
  * Added branding color (Issue #174)
  * Used libxml for xml parsing for ePubs (Issue #169)
  * Update README.md
  * Added Paypal Badge
  * Typo: “comma seperated” → comma-separated
  * Fixed xml parsing issue for ToC with namespace (Issue #160)
  * Updating travis to have trusty as the distribution
  * Fixed the issue of long titles not wrapping on the default
    cover (Issue #167)
  * Moved default covers out of 256x256 folder
  * Merge branch 'master' of https://github.com/babluboy/bookworm
* Sun Dec 24 2017 avvissu@yandex.by
- Update to 0.9.9:
  * Updated binary in appdata.xml to the RDNN executable name
  * Replaced icon files with RDNN (#157)
  * Updated RDNN executable change in contract and desktop files
  * Fixed RDNN issues for desktop icon (#158)
  * Renamed binary to match RDNN (#157)
  * Fixed an issue of bookworm hanging if the watched folder is
    not set
  * Fixed the issue of covers getting different numbers when
    moving from 0.9.2 to 0.9.5
  * Improvements for Search and Annotation Highlighting
  * Replaced nb.po with nb_NO.po and removed no.po
  * Altered the design to discover books (Issue #104)
* Tue Dec 19 2017 jengelh@inai.de
- Use improved find call execution.
- Ensure neutrality of description.
* Mon Dec  4 2017 avvissu@yandex.by
- Add macros: icon_theme_cache_post{un}, desktop_database_post{un},
  glib2_gsettings_schema_post{un}
* Wed Nov  8 2017 avvissu@yandex.by
- Initial package
